import React, { Suspense } from 'react';
import type { Metadata } from 'next';
import { useTranslations } from 'next-intl';
import { ProfileSettings } from '../../../../../components/Account';

export const metadata: Metadata = {
    title: 'Bbuddy - Account - Profile Settings',
    description: 'Bbuddy desc Profile settings'
};

export default function Settings({ params: { locale } }: { params: { locale: string } }) {
    const t = useTranslations('Account.Settings');

    return (
        <>
            <ol className="breadcrumb">
                <li className="breadcrumb-item active" aria-current="page">{t('title')}</li>
            </ol>
            <Suspense>
                <ProfileSettings
                    locale={locale}
                    photoDesc={t('photo-desc')}
                    placeholderName={t('name')}
                    placeholderSurname={t('surname')}
                    placeholderBirthday={t('birthday')}
                    placeholderEmail={t('email')}
                    changePasswordLink={t('change-password')}
                    saveButton={t('save')}
                />
            </Suspense>
        </>
    );
};
