'use client';

import React from 'react';
import styled from 'styled-components';
import { Button } from 'antd';
import { useSelectedLayoutSegment, usePathname } from 'next/navigation';
import { Link } from '../../navigation';
import { AUTH_TOKEN_KEY, AUTH_USER } from '../../constants/common';
import { deleteStorageKey } from '../../hooks/useLocalStorage';

const Logout = styled(Button)`
    width: 100%;
    height: 49px !important;
    color: #D93E5C !important;
    font-style: normal;
    font-weight: 600 !important;
    padding: 0 !important;
    font-size: 1.125rem !important;
    text-align: left !important;
`;

export const AccountMenu = ({ menu }: { menu: { path: string, title: string, count?: number }[] }) => {
    const selectedLayoutSegment = useSelectedLayoutSegment();
    const pathname = selectedLayoutSegment || '';
    const paths = usePathname();

    const onLogout = () => {
        deleteStorageKey(AUTH_TOKEN_KEY);
        deleteStorageKey(AUTH_USER);
        window?.location?.replace(`/${paths.split('/')[1]}/`);
    };

    const onDeleteAccount = () => {
        console.log('delete');
    };

    return (
        <ul className="list-sidebar">
            {menu.map(({ path, title, count }) => (
                <li key={path} className="list-sidebar__item">
                    <Link href={`/account/${path}` as any} className={path === pathname ? 'active' : ''}>
                        {title}
                        {count ? (
                            <span className="count">{count}</span>
                        ) : null}
                    </Link>
                </li>
            ))}
            <li className="list-sidebar__item">
                <Logout
                    type="link"
                    onClick={onLogout}
                >
                    Log Out
                </Logout>
            </li>
            <li className="list-sidebar__item">
                <Logout
                    type="link"
                    onClick={onDeleteAccount}
                >
                    Delete account
                </Logout>
            </li>
        </ul>
    );
};
