'use client';

import React, { useCallback, useEffect, useState } from 'react';
import { useSearchParams } from 'next/navigation';
import debounce from 'lodash/debounce';
import { useRouter } from '../../navigation';
import { AdditionalFilter } from '../../types/experts';
import { getObjectByFilter, getObjectByAdditionalFilter } from '../../utils/filter';
import { CustomInput, CustomSelect } from '../view';

type ExpertAdditionalFilterProps = {
    searchPlaceholder: string;
    sortLabel: string;
    basePath: string;
};

export const ExpertsAdditionalFilter = ({
    searchPlaceholder,
    sortLabel,
    basePath,
}: ExpertAdditionalFilterProps) => {
    const searchParams = useSearchParams();
    const router = useRouter();
    const [filter, setFilter] = useState<AdditionalFilter | undefined>(getObjectByAdditionalFilter(searchParams));

    const onChangeInput = useCallback(debounce((e: any) => {
        const newFilter: AdditionalFilter = { ...filter };

        if (e?.target?.value) {
            newFilter.text = e.target.value;
        } else {
            delete newFilter?.text;
        }

        setFilter(newFilter);
    }, 300), [filter]);

    const onChangeSort = useCallback((value: string) => {
        const newFilter: AdditionalFilter = { ...filter };

        if (value) {
            newFilter.coachSort = value;
        } else {
            delete newFilter?.coachSort;
        }

        setFilter(newFilter);
    }, [filter]);

    useEffect(() => {
        router.push({
            pathname: basePath as any,
            query: {
                ...getObjectByFilter(searchParams),
                ...filter
            }
        })
    }, [filter]);

    return (
        <div className="main-find__search">
            <div className="main-find__search__input">
                <CustomInput
                    placeholder={searchPlaceholder}
                    defaultValue={filter?.text}
                    onChange={onChangeInput}
                    allowClear
                />
            </div>
            <div className="main-find__search__sort">
                <CustomSelect
                    label={sortLabel}
                    value={filter?.coachSort}
                    onChange={onChangeSort}
                    options={[
                        // { value: 'byTop', label: 'By top views' },
                        { value: 'byPriceAscending', label: 'By price ascending' },
                        { value: 'byPriceDescending', label: 'By price descending' }
                        // { value: 'byRating', label: 'By rating' }
                    ]}
                />
            </div>
        </div>
    );
};
