import React from 'react';
import { getTranslations } from 'next-intl/server';
import { DEFAULT_PAGE_SIZE } from '../../constants/common';
import { getFilter } from '../../utils/filter';
import { getTagList, getLanguages } from '../../actions/tags';
import { getExpertsList } from '../../actions/experts';
import { ExpertsFilter } from './Filter';
import { ExpertsAdditionalFilter } from './AdditionalFilter';
import { ExpertsList } from './ExpertsList';

type ExpertsProps = {
    basePath?: string;
    locale: string;
    pageSize?: number;
};

export const Experts = async ({ basePath = '/', locale, pageSize = DEFAULT_PAGE_SIZE }: ExpertsProps) => {
    const t = await getTranslations('Experts');
    const searchData = await getTagList(locale);
    const languages = await getLanguages(locale);
    const filter = getFilter({ searchData, pageSize });
    const experts = await getExpertsList(filter, locale);

    return (
        <div className="row">
            <div className="col-xl-3 col-lg-4 d-none d-lg-block">
                <ExpertsFilter
                    searchData={searchData}
                    languages={languages}
                    basePath={basePath}
                    priceTitle={t('filter.price', { from: searchData?.sessionCostMin || 0, to: searchData?.sessionCostMax || 0 })}
                    durationTitle={t('filter.duration', { from: searchData?.sessionDurationMin || 0, to: searchData?.sessionDurationMax || 0 })}
                    buttonApply={t('filter.apply')}
                />
            </div>
            <div className="col-xl-9 col-lg-8 ">
                <ExpertsAdditionalFilter
                    searchPlaceholder={t('filter.search')}
                    sortLabel={t('filter.sort')}
                    basePath={basePath}
                />
                <ExpertsList
                    locale={locale}
                    data={experts}
                    basePath={basePath}
                    baseFilter={filter}
                    priceTitle={t('list.price')}
                    durationTitle={t('list.duration')}
                    detailButton={t('list.details')}
                    pageSize={pageSize}
                />
            </div>
        </div>
    );
};
