'use client';

import React, { FC, useState, useEffect } from 'react';
import { Button } from 'antd';
import { useSelectedLayoutSegment } from 'next/navigation';
import { styled } from 'styled-components';
import { Link } from '../../../navigation';
import { AUTH_TOKEN_KEY } from '../../../constants/common';
import { useLocalStorage } from '../../../hooks/useLocalStorage';
import { AuthModal } from '../../Modals/AuthModal';

type HeaderAuthLinksProps = {
    enterTitle: string;
    registerTitle: string;
    accountTitle: string;
    separatorClass?: string;
};

const LinkButton = styled(Button)`
    color: #66A5AD !important;
    font-size: 16px !important;
    height: auto !important;
    padding: 0 !important;
    font-style: normal !important;
    font-weight: 600 !important;
    line-height: normal !important;
`;

export const HeaderAuthLinks: FC<HeaderAuthLinksProps> = ({
    enterTitle,
    registerTitle,
    accountTitle,
    separatorClass = 'b-header__nav__list__line'
}) => {
    const [isOpenModal, setIsOpenModal] = useState<boolean>(false);
    const [mode, setMode] = useState<'enter' | 'register' | 'reset' | 'finish'>('enter');
    const selectedLayoutSegment = useSelectedLayoutSegment();
    const pathname = selectedLayoutSegment || '';
    const [token, setToken] = useLocalStorage(AUTH_TOKEN_KEY, '');

    useEffect(() => {
        if (!isOpenModal) {
            setMode('enter');
        }
    }, [isOpenModal]);

    const onOpen = (mode: 'enter' | 'register' | 'reset' | 'finish') => {
        setMode(mode);
        setIsOpenModal(true);
    };

    return token
        ? (
            <li>
                <Link href={'/account/sessions' as any} className={pathname === 'account' ? 'active' : ''}>{accountTitle}</Link>
            </li>
        )
        : (
            <>
                <li>
                    <LinkButton
                        type="link"
                        onClick={() => onOpen('register')}
                    >
                        {registerTitle}
                    </LinkButton>
                </li>
                <li>
                    <span className={separatorClass}>|</span>
                </li>
                <li>
                    <LinkButton
                        type="link"
                        onClick={() => onOpen('enter')}
                    >
                        {enterTitle}
                    </LinkButton>
                </li>
                <AuthModal
                    open={isOpenModal}
                    handleCancel={() => setIsOpenModal(false)}
                    mode={mode}
                    updateMode={setMode}
                    updateToken={setToken}
                />
            </>
    );
};
